/****************************************************************************************************
/******************* ESTIMATE COEFFICIENTS AND STANDARD ERRORS OF MAIN MODELS  **********************
/********************* FOR ALL WEIGHTS BETWEEN x2 - x20 AS SHOWN IN FIGURE **************************
/*********************** A1 OF THE SUPPLEMENTARY MATERIAL OF THE ARTICLE ****************************
/***************************************************************************************************/ 
 
// THE FOLLOWING CODE SHOWS HOW THE MODELS ARE ESTIMATED AND HOW THE ESTIMATES ARE STORED. 
// FIGURE A1 OF THE SUPPLEMENTARY MATERIAL IS MADE IN R (SEE OTHER CODE) WITH THE DTA-FILES CREATED WITH THE FOLLOWING CODE. 



/********************************************************************************************
************** COMPETITORS IF NOT IN SAME CONFERENCE (ALL WEIGHTS) **************************
*********************************************************************************************/


clear
cd "/Users/.../replication_archive/supplementary_material/Figure_A1/models"
set more off

/* create an empty dataset with the NSM_NSC_estimates.dta */

clear 

save NSM_NSC_estimates.dta, replace

clear
use steuern.dta
tsset cantonid year 

/* Model with SL x2 not in same conference */

xtpcse ks_150 sl_not_same_conf_x2_150 schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

matrix list e(b)
matrix list e(V)


/* Model with SL not in same conference for all weights */

qui foreach x in 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 {


   use steuern.dta

  xtpcse ks_150 sl_not_same_conf_x`x'_150 schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

matrix coef_n_reg_`x' = e(b)'
mat coef_sl_n_reg_`x' = coef_n_reg_`x'[1,1]

matrix ster_n_reg_`x' = e(V)' 
mat ster_sl_n_reg_`x' = ster_n_reg_`x'[1,1]

	use NSM_NSC_estimates.dta
	svmat coef_sl_n_reg_`x'	
	svmat ster_sl_n_reg_`x'
	
	save NSM_NSC_estimates.dta, replace
   
       noi display "." _c                                                  
    } 


/* Make a clean dataset with coefficient, SE and confidence intervals to make a graph */

clear
use NSM_NSC_estimates.dta

rename var1 X  
set obs 1
replace X = 2 in 1 
set obs 2
replace X = 3 in 2
set obs 3
replace X = 4 in 3
set obs 4 
replace X = 5 in 4
set obs 5 
replace X = 6 in 5
set obs 6 
replace X = 7 in 6
set obs 7 
replace X = 8 in 7
set obs 8 
replace X = 9 in 8
set obs 9 
replace X = 10 in 9
set obs 10 
replace X = 11 in 10
set obs 11
replace X = 12 in 11
set obs 12
replace X = 13 in 12
set obs 13
replace X = 14 in 13
set obs 14
replace X = 15 in 14
set obs 15
replace X = 16 in 15
set obs 16
replace X = 17 in 16
set obs 17
replace X = 18 in 17
set obs 18
replace X = 19 in 18
set obs 19
replace X = 20 in 19

g coef_n_reg=.
sum coef_sl_n_reg_21             
local c=r(max)
replace coef_n_reg in 1 = r(max)  
sum coef_sl_n_reg_31            
local c=r(max)
replace coef_n_reg in 2 = r(max)  
sum coef_sl_n_reg_41            
local c=r(max)
replace coef_n_reg in 3 = r(max)  
sum coef_sl_n_reg_51            
local c=r(max)
replace coef_n_reg in 4 = r(max)  
sum coef_sl_n_reg_61            
local c=r(max)
replace coef_n_reg in 5 = r(max)  
sum coef_sl_n_reg_71            
local c=r(max)
replace coef_n_reg in 6 = r(max)  
sum coef_sl_n_reg_81            
local c=r(max)
replace coef_n_reg in 7 = r(max)  
sum coef_sl_n_reg_91            
local c=r(max)
replace coef_n_reg in 8 = r(max)  
sum coef_sl_n_reg_101           
local c=r(max)
replace coef_n_reg in 9 = r(max) 
sum coef_sl_n_reg_111                  
local c=r(max)
replace coef_n_reg in 10 = r(max)  
sum coef_sl_n_reg_121                
local c=r(max)
replace coef_n_reg in 11 = r(max)  
sum coef_sl_n_reg_131                 
local c=r(max)
replace coef_n_reg in 12 = r(max)  
sum coef_sl_n_reg_141                  
local c=r(max)
replace coef_n_reg in 13 = r(max)  
sum coef_sl_n_reg_151                  
local c=r(max)
replace coef_n_reg in 14 = r(max)  
sum coef_sl_n_reg_161                  
local c=r(max)
replace coef_n_reg in 15 = r(max)  
sum coef_sl_n_reg_171                  
local c=r(max)
replace coef_n_reg in 16 = r(max)  
sum coef_sl_n_reg_181                  
local c=r(max)
replace coef_n_reg in 17 = r(max)  
sum coef_sl_n_reg_191                  
local c=r(max)
replace coef_n_reg in 18 = r(max)  
sum coef_sl_n_reg_201                  
local c=r(max)
replace coef_n_reg in 19 = r(max)  


g var_n_reg=.
sum ster_sl_n_reg_21             
local c=r(max)
replace var_n_reg in 1 = r(max)  
sum ster_sl_n_reg_31            
local c=r(max)
replace var_n_reg in 2 = r(max)  
sum ster_sl_n_reg_41            
local c=r(max)
replace var_n_reg in 3 = r(max)  
sum ster_sl_n_reg_51            
local c=r(max)
replace var_n_reg in 4 = r(max)  
sum ster_sl_n_reg_61            
local c=r(max)
replace var_n_reg in 5 = r(max)  
sum ster_sl_n_reg_71            
local c=r(max)
replace var_n_reg in 6 = r(max)  
sum ster_sl_n_reg_81            
local c=r(max)
replace var_n_reg in 7 = r(max)  
sum ster_sl_n_reg_91            
local c=r(max)
replace var_n_reg in 8 = r(max)  
sum ster_sl_n_reg_101           
local c=r(max)
replace var_n_reg in 9 = r(max) 
sum ster_sl_n_reg_111                  
local c=r(max)
replace var_n_reg in 10 = r(max)  
sum ster_sl_n_reg_121                
local c=r(max)
replace var_n_reg in 11 = r(max)  
sum ster_sl_n_reg_131                 
local c=r(max)
replace var_n_reg in 12 = r(max)  
sum ster_sl_n_reg_141                  
local c=r(max)
replace var_n_reg in 13 = r(max)  
sum ster_sl_n_reg_151                  
local c=r(max)
replace var_n_reg in 14 = r(max)  
sum ster_sl_n_reg_161                  
local c=r(max)
replace var_n_reg in 15 = r(max)  
sum ster_sl_n_reg_171                  
local c=r(max)
replace var_n_reg in 16 = r(max)  
sum ster_sl_n_reg_181                  
local c=r(max)
replace var_n_reg in 17 = r(max)  
sum ster_sl_n_reg_191                  
local c=r(max)
replace var_n_reg in 18 = r(max)  
sum ster_sl_n_reg_201                  
local c=r(max)
replace var_n_reg in 19 = r(max)  

g ster_n_reg = var_n_reg^0.5

save, replace




/********************************************************************************************
************** COMPETITORS IF IN SAME CONFERENCE (ALL WEIGHTS) ******************************
*********************************************************************************************/


clear 

save NSM_SC_estimates.dta, replace

clear
use steuern.dta
tsset cantonid year 


/* Model with SL in same conference for all weights */

qui foreach x in 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 {

use steuern.dta

  xtpcse ks_150 sl_same_conf_x`x'_150 schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

matrix coef_n_reg_`x' = e(b)'
mat coef_sl_n_reg_`x' = coef_n_reg_`x'[1,1]

matrix ster_n_reg_`x' = e(V)' 
mat ster_sl_n_reg_`x' = ster_n_reg_`x'[1,1]

	use NSM_SC_estimates.dta
	svmat coef_sl_n_reg_`x'	
	svmat ster_sl_n_reg_`x'
	
	save NSM_SC_estimates.dta, replace
   
       noi display "." _c                                                  
    } 


/* Make a clean dataset with coefficient, SE and confidence intervals to make a graph */

clear
use NSM_SC_estimates.dta

rename var1 X  
set obs 1
replace X = 2 in 1 
set obs 2
replace X = 3 in 2
set obs 3
replace X = 4 in 3
set obs 4 
replace X = 5 in 4
set obs 5 
replace X = 6 in 5
set obs 6 
replace X = 7 in 6
set obs 7 
replace X = 8 in 7
set obs 8 
replace X = 9 in 8
set obs 9 
replace X = 10 in 9
set obs 10 
replace X = 11 in 10
set obs 11
replace X = 12 in 11
set obs 12
replace X = 13 in 12
set obs 13
replace X = 14 in 13
set obs 14
replace X = 15 in 14
set obs 15
replace X = 16 in 15
set obs 16
replace X = 17 in 16
set obs 17
replace X = 18 in 17
set obs 18
replace X = 19 in 18
set obs 19
replace X = 20 in 19

g coef_n_reg=.
sum coef_sl_n_reg_21             
local c=r(max)
replace coef_n_reg in 1 = r(max)  
sum coef_sl_n_reg_31            
local c=r(max)
replace coef_n_reg in 2 = r(max)  
sum coef_sl_n_reg_41            
local c=r(max)
replace coef_n_reg in 3 = r(max)  
sum coef_sl_n_reg_51            
local c=r(max)
replace coef_n_reg in 4 = r(max)  
sum coef_sl_n_reg_61            
local c=r(max)
replace coef_n_reg in 5 = r(max)  
sum coef_sl_n_reg_71            
local c=r(max)
replace coef_n_reg in 6 = r(max)  
sum coef_sl_n_reg_81            
local c=r(max)
replace coef_n_reg in 7 = r(max)  
sum coef_sl_n_reg_91            
local c=r(max)
replace coef_n_reg in 8 = r(max)  
sum coef_sl_n_reg_101           
local c=r(max)
replace coef_n_reg in 9 = r(max) 
sum coef_sl_n_reg_111                  
local c=r(max)
replace coef_n_reg in 10 = r(max)  
sum coef_sl_n_reg_121                
local c=r(max)
replace coef_n_reg in 11 = r(max)  
sum coef_sl_n_reg_131                 
local c=r(max)
replace coef_n_reg in 12 = r(max)  
sum coef_sl_n_reg_141                  
local c=r(max)
replace coef_n_reg in 13 = r(max)  
sum coef_sl_n_reg_151                  
local c=r(max)
replace coef_n_reg in 14 = r(max)  
sum coef_sl_n_reg_161                  
local c=r(max)
replace coef_n_reg in 15 = r(max)  
sum coef_sl_n_reg_171                  
local c=r(max)
replace coef_n_reg in 16 = r(max)  
sum coef_sl_n_reg_181                  
local c=r(max)
replace coef_n_reg in 17 = r(max)  
sum coef_sl_n_reg_191                  
local c=r(max)
replace coef_n_reg in 18 = r(max)  
sum coef_sl_n_reg_201                  
local c=r(max)
replace coef_n_reg in 19 = r(max)  


g var_n_reg=.
sum ster_sl_n_reg_21             
local c=r(max)
replace var_n_reg in 1 = r(max)  
sum ster_sl_n_reg_31            
local c=r(max)
replace var_n_reg in 2 = r(max)  
sum ster_sl_n_reg_41            
local c=r(max)
replace var_n_reg in 3 = r(max)  
sum ster_sl_n_reg_51            
local c=r(max)
replace var_n_reg in 4 = r(max)  
sum ster_sl_n_reg_61            
local c=r(max)
replace var_n_reg in 5 = r(max)  
sum ster_sl_n_reg_71            
local c=r(max)
replace var_n_reg in 6 = r(max)  
sum ster_sl_n_reg_81            
local c=r(max)
replace var_n_reg in 7 = r(max)  
sum ster_sl_n_reg_91            
local c=r(max)
replace var_n_reg in 8 = r(max)  
sum ster_sl_n_reg_101           
local c=r(max)
replace var_n_reg in 9 = r(max) 
sum ster_sl_n_reg_111                  
local c=r(max)
replace var_n_reg in 10 = r(max)  
sum ster_sl_n_reg_121                
local c=r(max)
replace var_n_reg in 11 = r(max)  
sum ster_sl_n_reg_131                 
local c=r(max)
replace var_n_reg in 12 = r(max)  
sum ster_sl_n_reg_141                  
local c=r(max)
replace var_n_reg in 13 = r(max)  
sum ster_sl_n_reg_151                  
local c=r(max)
replace var_n_reg in 14 = r(max)  
sum ster_sl_n_reg_161                  
local c=r(max)
replace var_n_reg in 15 = r(max)  
sum ster_sl_n_reg_171                  
local c=r(max)
replace var_n_reg in 16 = r(max)  
sum ster_sl_n_reg_181                  
local c=r(max)
replace var_n_reg in 17 = r(max)  
sum ster_sl_n_reg_191                  
local c=r(max)
replace var_n_reg in 18 = r(max)  
sum ster_sl_n_reg_201                  
local c=r(max)
replace var_n_reg in 19 = r(max)  

g ster_n_reg = var_n_reg^0.5

save, replace





/***********************************************************************************************************
********** COMPETITORS IN SAME CONFERENCE AND NOT SAME CONFERENCE IN SAME MODEL (ALL WEIGHTS) **************
************************************************************************************************************/


/* create an empty dataset with the name SM_estimates.dta */

clear 

save SM_estimates.dta, replace


clear
use steuern.dta
tsset cantonid year 


/* Model with SL in same conference and not in same conference in same model for all weights */

qui foreach x in 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20  {

   use steuern.dta

  xtpcse ks_150 sl_same_conf_x`x'_150 sl_not_same_conf_x`x'_150 schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

matrix coef_n_`x' = e(b)'
mat coef_sl_n_`x' = coef_n_`x'[1,1]
matrix coef_reg_no_n_`x' = e(b)'
mat coef_sl_reg_no_n_`x' = coef_reg_no_n_`x'[2,1]

matrix ster_n_`x' = e(V)' 
mat ster_sl_n_`x' = ster_n_`x'[1,1]
matrix ster_reg_no_n_`x' = e(V)' 
mat ster_sl_reg_no_n_`x' = ster_reg_no_n_`x'[2,2]


	use SM_estimates.dta
	svmat coef_sl_n_`x'
	svmat coef_sl_reg_no_n_`x'
	
	svmat ster_sl_n_`x'
	svmat ster_sl_reg_no_n_`x'
	

	save SM_estimates.dta, replace
   
       noi display "." _c                                                  
    } 



/* Make a clean dataset with coefficient, SE and confidence intervals to make a graph */

clear
use SM_estimates.dta

rename var1 X  
set obs 1
replace X = 2 in 1 
set obs 2
replace X = 3 in 2
set obs 3
replace X = 4 in 3
set obs 4 
replace X = 5 in 4
set obs 5 
replace X = 6 in 5
set obs 6 
replace X = 7 in 6
set obs 7 
replace X = 8 in 7
set obs 8 
replace X = 9 in 8
set obs 9 
replace X = 10 in 9
set obs 10 
replace X = 11 in 10
set obs 11
replace X = 12 in 11
set obs 12
replace X = 13 in 12
set obs 13
replace X = 14 in 13
set obs 14
replace X = 15 in 14
set obs 15
replace X = 16 in 15
set obs 16
replace X = 17 in 16
set obs 17
replace X = 18 in 17
set obs 18
replace X = 19 in 18
set obs 19
replace X = 20 in 19

g coef_n_reg=.
sum coef_sl_n_21             
local c=r(max)
replace coef_n_reg in 1 = r(max)  
sum coef_sl_n_31            
local c=r(max)
replace coef_n_reg in 2 = r(max)  
sum coef_sl_n_41            
local c=r(max)
replace coef_n_reg in 3 = r(max)  
sum coef_sl_n_51            
local c=r(max)
replace coef_n_reg in 4 = r(max)  
sum coef_sl_n_61            
local c=r(max)
replace coef_n_reg in 5 = r(max)  
sum coef_sl_n_71            
local c=r(max)
replace coef_n_reg in 6 = r(max)  
sum coef_sl_n_81            
local c=r(max)
replace coef_n_reg in 7 = r(max)  
sum coef_sl_n_91            
local c=r(max)
replace coef_n_reg in 8 = r(max)  
sum coef_sl_n_101           
local c=r(max)
replace coef_n_reg in 9 = r(max) 
sum coef_sl_n_111                  
local c=r(max)
replace coef_n_reg in 10 = r(max)  
sum coef_sl_n_121                
local c=r(max)
replace coef_n_reg in 11 = r(max)  
sum coef_sl_n_131                 
local c=r(max)
replace coef_n_reg in 12 = r(max)  
sum coef_sl_n_141                  
local c=r(max)
replace coef_n_reg in 13 = r(max)  
sum coef_sl_n_151                  
local c=r(max)
replace coef_n_reg in 14 = r(max)  
sum coef_sl_n_161                  
local c=r(max)
replace coef_n_reg in 15 = r(max)  
sum coef_sl_n_171                  
local c=r(max)
replace coef_n_reg in 16 = r(max)  
sum coef_sl_n_181                  
local c=r(max)
replace coef_n_reg in 17 = r(max)  
sum coef_sl_n_191                  
local c=r(max)
replace coef_n_reg in 18 = r(max)  
sum coef_sl_n_201                  
local c=r(max)
replace coef_n_reg in 19 = r(max) 


g coef_n_NSC=.
sum coef_sl_reg_no_n_21             
local c=r(max)
replace coef_n_NSC in 1 = r(max)  
sum coef_sl_reg_no_n_31            
local c=r(max)
replace coef_n_NSC in 2 = r(max)  
sum coef_sl_reg_no_n_41            
local c=r(max)
replace coef_n_NSC in 3 = r(max)  
sum coef_sl_reg_no_n_51            
local c=r(max)
replace coef_n_NSC in 4 = r(max)  
sum coef_sl_reg_no_n_61            
local c=r(max)
replace coef_n_NSC in 5 = r(max)  
sum coef_sl_reg_no_n_71            
local c=r(max)
replace coef_n_NSC in 6 = r(max)  
sum coef_sl_reg_no_n_81            
local c=r(max)
replace coef_n_NSC in 7 = r(max)  
sum coef_sl_reg_no_n_91            
local c=r(max)
replace coef_n_NSC in 8 = r(max)  
sum coef_sl_reg_no_n_101           
local c=r(max)
replace coef_n_NSC in 9 = r(max) 
sum coef_sl_reg_no_n_111                  
local c=r(max)
replace coef_n_NSC in 10 = r(max)  
sum coef_sl_reg_no_n_121                
local c=r(max)
replace coef_n_NSC in 11 = r(max)  
sum coef_sl_reg_no_n_131                 
local c=r(max)
replace coef_n_NSC in 12 = r(max)  
sum coef_sl_reg_no_n_141                  
local c=r(max)
replace coef_n_NSC in 13 = r(max)  
sum coef_sl_reg_no_n_151                  
local c=r(max)
replace coef_n_NSC in 14 = r(max)  
sum coef_sl_reg_no_n_161                  
local c=r(max)
replace coef_n_NSC in 15 = r(max)  
sum coef_sl_reg_no_n_171                  
local c=r(max)
replace coef_n_NSC in 16 = r(max)  
sum coef_sl_reg_no_n_181                  
local c=r(max)
replace coef_n_NSC in 17 = r(max)  
sum coef_sl_reg_no_n_191                  
local c=r(max)
replace coef_n_NSC in 18 = r(max)  
sum coef_sl_reg_no_n_201                  
local c=r(max)
replace coef_n_NSC in 19 = r(max) 


g var_n_reg=.
sum ster_sl_n_21             
local c=r(max)
replace var_n_reg in 1 = r(max)  
sum ster_sl_n_31            
local c=r(max)
replace var_n_reg in 2 = r(max)  
sum ster_sl_n_41            
local c=r(max)
replace var_n_reg in 3 = r(max)  
sum ster_sl_n_51            
local c=r(max)
replace var_n_reg in 4 = r(max)  
sum ster_sl_n_61            
local c=r(max)
replace var_n_reg in 5 = r(max)  
sum ster_sl_n_71            
local c=r(max)
replace var_n_reg in 6 = r(max)  
sum ster_sl_n_81            
local c=r(max)
replace var_n_reg in 7 = r(max)  
sum ster_sl_n_91            
local c=r(max)
replace var_n_reg in 8 = r(max)  
sum ster_sl_n_101           
local c=r(max)
replace var_n_reg in 9 = r(max) 
sum ster_sl_n_111                  
local c=r(max)
replace var_n_reg in 10 = r(max)  
sum ster_sl_n_121                
local c=r(max)
replace var_n_reg in 11 = r(max)  
sum ster_sl_n_131                 
local c=r(max)
replace var_n_reg in 12 = r(max)  
sum ster_sl_n_141                  
local c=r(max)
replace var_n_reg in 13 = r(max)  
sum ster_sl_n_151                  
local c=r(max)
replace var_n_reg in 14 = r(max)  
sum ster_sl_n_161                  
local c=r(max)
replace var_n_reg in 15 = r(max)  
sum ster_sl_n_171                  
local c=r(max)
replace var_n_reg in 16 = r(max)  
sum ster_sl_n_181                  
local c=r(max)
replace var_n_reg in 17 = r(max)  
sum ster_sl_n_191                  
local c=r(max)
replace var_n_reg in 18 = r(max)  
sum ster_sl_n_201                  
local c=r(max)
replace var_n_reg in 19 = r(max) 


g var_n_NSC=.
sum ster_sl_reg_no_n_21             
local c=r(max)
replace var_n_NSC in 1 = r(max)  
sum ster_sl_reg_no_n_31            
local c=r(max)
replace var_n_NSC in 2 = r(max)  
sum ster_sl_reg_no_n_41            
local c=r(max)
replace var_n_NSC in 3 = r(max)  
sum ster_sl_reg_no_n_51            
local c=r(max)
replace var_n_NSC in 4 = r(max)  
sum ster_sl_reg_no_n_61            
local c=r(max)
replace var_n_NSC in 5 = r(max)  
sum ster_sl_reg_no_n_71            
local c=r(max)
replace var_n_NSC in 6 = r(max)  
sum ster_sl_reg_no_n_81            
local c=r(max)
replace var_n_NSC in 7 = r(max)  
sum ster_sl_reg_no_n_91            
local c=r(max)
replace var_n_NSC in 8 = r(max)  
sum ster_sl_reg_no_n_101           
local c=r(max)
replace var_n_NSC in 9 = r(max) 
sum ster_sl_reg_no_n_111                  
local c=r(max)
replace var_n_NSC in 10 = r(max)  
sum ster_sl_reg_no_n_121                
local c=r(max)
replace var_n_NSC in 11 = r(max)  
sum ster_sl_reg_no_n_131                 
local c=r(max)
replace var_n_NSC in 12 = r(max)  
sum ster_sl_reg_no_n_141                  
local c=r(max)
replace var_n_NSC in 13 = r(max)  
sum ster_sl_reg_no_n_151                  
local c=r(max)
replace var_n_NSC in 14 = r(max)  
sum ster_sl_reg_no_n_161                  
local c=r(max)
replace var_n_NSC in 15 = r(max)  
sum ster_sl_reg_no_n_171                  
local c=r(max)
replace var_n_NSC in 16 = r(max)  
sum ster_sl_reg_no_n_181                  
local c=r(max)
replace var_n_NSC in 17 = r(max)  
sum ster_sl_reg_no_n_191                  
local c=r(max)
replace var_n_NSC in 18 = r(max)  
sum ster_sl_reg_no_n_201                  
local c=r(max)
replace var_n_NSC in 19 = r(max) 



g ster_n = var_n_reg^0.5
g ster_reg_no_n = var_n_NSC^0.5

save, replace


